<?php


/**
 * Matches bible verse references
 * No allowance for multiple verse references with only one book name!
 */
class SI_EntryVerse extends SI_Entry {

    public $order   = 20;
    public $type    = 'verse';
    public $section = 2;

    // first is for Dokuwiki syntax parser matching, second for internal lexing
    public $regex = '(?:[123]\h?)?(?:[A-Z][a-zA-Z]+|Song of Solomon)\.?\h?1?[0-9]?[0-9]:\d{1,3}(?:[,-]\h?\d{1,3})*';
    private $_regex = '`([123]\h?)?([A-Z][a-zA-Z]+|Song of Solomon)\.?\h?(1?[0-9]?[0-9]):(\d{1,3}([,-]\h?\d{1,3})*)`';


    function __construct() {
        // array of possible abbreviations (space separated)
        $this->abbrs = file(DOKU_PLUGIN . 'subjectindex/plugins/bible_abbr.txt', FILE_IGNORE_NEW_LINES | FILE_TEXT);
        // array of proper book names
        $this->books = file(DOKU_PLUGIN . 'subjectindex/plugins/bible_books.txt', FILE_IGNORE_NEW_LINES | FILE_TEXT);
        $this->verses = file(DOKU_PLUGIN . 'subjectindex/plugins/bible_verses.txt', FILE_IGNORE_NEW_LINES);
        $this->book_index = $this->_book_index();
    }


    function match($text) {
        $this->items = array();
        $matches = array();
        $matched = false;
        $hits = preg_match_all($this->_regex, $text, $matches, PREG_SET_ORDER);
        if ($hits > 0) {
            foreach ($matches as $match) {
                $num = trim($match[1]);
                $name = trim($match[2]);
                $abbr = $num . strtolower($name);
                $book = (empty($num)) ? $name : $num . ' ' . $name;
                $chp = $match[3];
                $verse = $match[4];
                // abbreviation match test
                $hit = (preg_grep('/(^|\s)' . $abbr . '($|\s)/', $this->abbrs));
                // try for a full book name match also if abbr fails
                if (empty($hit)) {
                    $hit = preg_grep('/(^|\s)' . $book . '($|\s)/', $this->books);
                }
                if ( ! empty($hit)) {
                    $num = key($hit);   // line number in abbr list, used to keep books in correct order
                    $book = $this->books[$num];
                    $item = &$this->items[];

                    $item['display'] = $book . ' ' . $chp . ':' . $verse;
                    // add an ordinal to keep the book names in correct order
                    $item['entry'] = $num . '.' . $book . '/' . $book . ' ' . $chp . ':/' . $verse;
                    $item['section'] = $this->section;
                    $item['type'] = $this->type;
                    $item['star'] = false;  // always ignored!
                    $item['title'] = $this->_get_verse($book, $chp, $verse);
                    $matched = true;
                }
            }
            return $matched;
        }
        return false;
    }

    /**
     * Returns a bible verse
     * @param string $book
     * @param string $chapter
     * @param string $verse
     * @return string
     */
    private function _get_verse($book, $chapter, $verse) {
        $result = '';
        $book = strtolower($book);
        $chapter = (int) $chapter;
        $verse = (int) $verse;
        if (isset($this->book_index[$book]) && isset($this->book_index[$book][$chapter])) {
            $result = $this->verses[$this->book_index[$book][$chapter] + $verse];
        }
        return $result;
    }


    private function _book_index() {
        $book_index = array();
        $book_index['genesis'][1] = 0;
        $book_index['genesis'][2] = 31;
        $book_index['genesis'][3] = 56;
        $book_index['genesis'][4] = 80;
        $book_index['genesis'][5] = 106;
        $book_index['genesis'][6] = 138;
        $book_index['genesis'][7] = 160;
        $book_index['genesis'][8] = 184;
        $book_index['genesis'][9] = 206;
        $book_index['genesis'][10] = 235;
        $book_index['genesis'][11] = 267;
        $book_index['genesis'][12] = 299;
        $book_index['genesis'][13] = 319;
        $book_index['genesis'][14] = 337;
        $book_index['genesis'][15] = 361;
        $book_index['genesis'][16] = 382;
        $book_index['genesis'][17] = 398;
        $book_index['genesis'][18] = 425;
        $book_index['genesis'][19] = 458;
        $book_index['genesis'][20] = 496;
        $book_index['genesis'][21] = 514;
        $book_index['genesis'][22] = 548;
        $book_index['genesis'][23] = 572;
        $book_index['genesis'][24] = 592;
        $book_index['genesis'][25] = 659;
        $book_index['genesis'][26] = 693;
        $book_index['genesis'][27] = 728;
        $book_index['genesis'][28] = 774;
        $book_index['genesis'][29] = 796;
        $book_index['genesis'][30] = 831;
        $book_index['genesis'][31] = 874;
        $book_index['genesis'][32] = 929;
        $book_index['genesis'][33] = 961;
        $book_index['genesis'][34] = 981;
        $book_index['genesis'][35] = 1012;
        $book_index['genesis'][36] = 1041;
        $book_index['genesis'][37] = 1084;
        $book_index['genesis'][38] = 1120;
        $book_index['genesis'][39] = 1150;
        $book_index['genesis'][40] = 1173;
        $book_index['genesis'][41] = 1196;
        $book_index['genesis'][42] = 1253;
        $book_index['genesis'][43] = 1291;
        $book_index['genesis'][44] = 1325;
        $book_index['genesis'][45] = 1359;
        $book_index['genesis'][46] = 1387;
        $book_index['genesis'][47] = 1421;
        $book_index['genesis'][48] = 1452;
        $book_index['genesis'][49] = 1474;
        $book_index['genesis'][50] = 1507;
        $book_index['exodus'][1] = 1533;
        $book_index['exodus'][2] = 1555;
        $book_index['exodus'][3] = 1580;
        $book_index['exodus'][4] = 1602;
        $book_index['exodus'][5] = 1633;
        $book_index['exodus'][6] = 1656;
        $book_index['exodus'][7] = 1686;
        $book_index['exodus'][8] = 1711;
        $book_index['exodus'][9] = 1743;
        $book_index['exodus'][10] = 1778;
        $book_index['exodus'][11] = 1807;
        $book_index['exodus'][12] = 1817;
        $book_index['exodus'][13] = 1868;
        $book_index['exodus'][14] = 1890;
        $book_index['exodus'][15] = 1921;
        $book_index['exodus'][16] = 1948;
        $book_index['exodus'][17] = 1984;
        $book_index['exodus'][18] = 2000;
        $book_index['exodus'][19] = 2027;
        $book_index['exodus'][20] = 2052;
        $book_index['exodus'][21] = 2078;
        $book_index['exodus'][22] = 2114;
        $book_index['exodus'][23] = 2145;
        $book_index['exodus'][24] = 2178;
        $book_index['exodus'][25] = 2196;
        $book_index['exodus'][26] = 2236;
        $book_index['exodus'][27] = 2273;
        $book_index['exodus'][28] = 2294;
        $book_index['exodus'][29] = 2337;
        $book_index['exodus'][30] = 2383;
        $book_index['exodus'][31] = 2421;
        $book_index['exodus'][32] = 2439;
        $book_index['exodus'][33] = 2474;
        $book_index['exodus'][34] = 2497;
        $book_index['exodus'][35] = 2532;
        $book_index['exodus'][36] = 2567;
        $book_index['exodus'][37] = 2605;
        $book_index['exodus'][38] = 2634;
        $book_index['exodus'][39] = 2665;
        $book_index['exodus'][40] = 2708;
        $book_index['leviticus'][1] = 2746;
        $book_index['leviticus'][2] = 2763;
        $book_index['leviticus'][3] = 2779;
        $book_index['leviticus'][4] = 2796;
        $book_index['leviticus'][5] = 2831;
        $book_index['leviticus'][6] = 2850;
        $book_index['leviticus'][7] = 2880;
        $book_index['leviticus'][8] = 2918;
        $book_index['leviticus'][9] = 2954;
        $book_index['leviticus'][10] = 2978;
        $book_index['leviticus'][11] = 2998;
        $book_index['leviticus'][12] = 3045;
        $book_index['leviticus'][13] = 3053;
        $book_index['leviticus'][14] = 3112;
        $book_index['leviticus'][15] = 3169;
        $book_index['leviticus'][16] = 3202;
        $book_index['leviticus'][17] = 3236;
        $book_index['leviticus'][18] = 3252;
        $book_index['leviticus'][19] = 3282;
        $book_index['leviticus'][20] = 3319;
        $book_index['leviticus'][21] = 3346;
        $book_index['leviticus'][22] = 3370;
        $book_index['leviticus'][23] = 3403;
        $book_index['leviticus'][24] = 3447;
        $book_index['leviticus'][25] = 3470;
        $book_index['leviticus'][26] = 3525;
        $book_index['leviticus'][27] = 3571;
        $book_index['numbers'][1] = 3605;
        $book_index['numbers'][2] = 3659;
        $book_index['numbers'][3] = 3693;
        $book_index['numbers'][4] = 3744;
        $book_index['numbers'][5] = 3793;
        $book_index['numbers'][6] = 3824;
        $book_index['numbers'][7] = 3851;
        $book_index['numbers'][8] = 3940;
        $book_index['numbers'][9] = 3966;
        $book_index['numbers'][10] = 3989;
        $book_index['numbers'][11] = 4025;
        $book_index['numbers'][12] = 4060;
        $book_index['numbers'][13] = 4076;
        $book_index['numbers'][14] = 4109;
        $book_index['numbers'][15] = 4154;
        $book_index['numbers'][16] = 4195;
        $book_index['numbers'][17] = 4245;
        $book_index['numbers'][18] = 4258;
        $book_index['numbers'][19] = 4290;
        $book_index['numbers'][20] = 4312;
        $book_index['numbers'][21] = 4341;
        $book_index['numbers'][22] = 4376;
        $book_index['numbers'][23] = 4417;
        $book_index['numbers'][24] = 4447;
        $book_index['numbers'][25] = 4472;
        $book_index['numbers'][26] = 4490;
        $book_index['numbers'][27] = 4555;
        $book_index['numbers'][28] = 4578;
        $book_index['numbers'][29] = 4609;
        $book_index['numbers'][30] = 4649;
        $book_index['numbers'][31] = 4665;
        $book_index['numbers'][32] = 4719;
        $book_index['numbers'][33] = 4761;
        $book_index['numbers'][34] = 4817;
        $book_index['numbers'][35] = 4846;
        $book_index['numbers'][36] = 4880;
        $book_index['deuteronomy'][1] = 4893;
        $book_index['deuteronomy'][2] = 4939;
        $book_index['deuteronomy'][3] = 4976;
        $book_index['deuteronomy'][4] = 5005;
        $book_index['deuteronomy'][5] = 5054;
        $book_index['deuteronomy'][6] = 5087;
        $book_index['deuteronomy'][7] = 5112;
        $book_index['deuteronomy'][8] = 5138;
        $book_index['deuteronomy'][9] = 5158;
        $book_index['deuteronomy'][10] = 5187;
        $book_index['deuteronomy'][11] = 5209;
        $book_index['deuteronomy'][12] = 5241;
        $book_index['deuteronomy'][13] = 5273;
        $book_index['deuteronomy'][14] = 5291;
        $book_index['deuteronomy'][15] = 5320;
        $book_index['deuteronomy'][16] = 5343;
        $book_index['deuteronomy'][17] = 5365;
        $book_index['deuteronomy'][18] = 5385;
        $book_index['deuteronomy'][19] = 5407;
        $book_index['deuteronomy'][20] = 5428;
        $book_index['deuteronomy'][21] = 5448;
        $book_index['deuteronomy'][22] = 5471;
        $book_index['deuteronomy'][23] = 5501;
        $book_index['deuteronomy'][24] = 5526;
        $book_index['deuteronomy'][25] = 5548;
        $book_index['deuteronomy'][26] = 5567;
        $book_index['deuteronomy'][27] = 5586;
        $book_index['deuteronomy'][28] = 5612;
        $book_index['deuteronomy'][29] = 5680;
        $book_index['deuteronomy'][30] = 5709;
        $book_index['deuteronomy'][31] = 5729;
        $book_index['deuteronomy'][32] = 5759;
        $book_index['deuteronomy'][33] = 5811;
        $book_index['deuteronomy'][34] = 5840;
        $book_index['joshua'][1] = 5852;
        $book_index['joshua'][2] = 5870;
        $book_index['joshua'][3] = 5894;
        $book_index['joshua'][4] = 5911;
        $book_index['joshua'][5] = 5935;
        $book_index['joshua'][6] = 5950;
        $book_index['joshua'][7] = 5977;
        $book_index['joshua'][8] = 6003;
        $book_index['joshua'][9] = 6038;
        $book_index['joshua'][10] = 6065;
        $book_index['joshua'][11] = 6108;
        $book_index['joshua'][12] = 6131;
        $book_index['joshua'][13] = 6155;
        $book_index['joshua'][14] = 6188;
        $book_index['joshua'][15] = 6203;
        $book_index['joshua'][16] = 6266;
        $book_index['joshua'][17] = 6276;
        $book_index['joshua'][18] = 6294;
        $book_index['joshua'][19] = 6322;
        $book_index['joshua'][20] = 6373;
        $book_index['joshua'][21] = 6382;
        $book_index['joshua'][22] = 6427;
        $book_index['joshua'][23] = 6461;
        $book_index['joshua'][24] = 6477;
        $book_index['judges'][1] = 6510;
        $book_index['judges'][2] = 6546;
        $book_index['judges'][3] = 6569;
        $book_index['judges'][4] = 6600;
        $book_index['judges'][5] = 6624;
        $book_index['judges'][6] = 6655;
        $book_index['judges'][7] = 6695;
        $book_index['judges'][8] = 6720;
        $book_index['judges'][9] = 6755;
        $book_index['judges'][10] = 6812;
        $book_index['judges'][11] = 6830;
        $book_index['judges'][12] = 6870;
        $book_index['judges'][13] = 6885;
        $book_index['judges'][14] = 6910;
        $book_index['judges'][15] = 6930;
        $book_index['judges'][16] = 6950;
        $book_index['judges'][17] = 6981;
        $book_index['judges'][18] = 6994;
        $book_index['judges'][19] = 7025;
        $book_index['judges'][20] = 7055;
        $book_index['judges'][21] = 7103;
        $book_index['ruth'][1] = 7128;
        $book_index['ruth'][2] = 7150;
        $book_index['ruth'][3] = 7173;
        $book_index['ruth'][4] = 7191;
        $book_index['1 samuel'][1] = 7213;
        $book_index['1 samuel'][2] = 7241;
        $book_index['1 samuel'][3] = 7277;
        $book_index['1 samuel'][4] = 7298;
        $book_index['1 samuel'][5] = 7320;
        $book_index['1 samuel'][6] = 7332;
        $book_index['1 samuel'][7] = 7353;
        $book_index['1 samuel'][8] = 7370;
        $book_index['1 samuel'][9] = 7392;
        $book_index['1 samuel'][10] = 7419;
        $book_index['1 samuel'][11] = 7446;
        $book_index['1 samuel'][12] = 7461;
        $book_index['1 samuel'][13] = 7486;
        $book_index['1 samuel'][14] = 7509;
        $book_index['1 samuel'][15] = 7561;
        $book_index['1 samuel'][16] = 7596;
        $book_index['1 samuel'][17] = 7619;
        $book_index['1 samuel'][18] = 7677;
        $book_index['1 samuel'][19] = 7707;
        $book_index['1 samuel'][20] = 7731;
        $book_index['1 samuel'][21] = 7773;
        $book_index['1 samuel'][22] = 7788;
        $book_index['1 samuel'][23] = 7811;
        $book_index['1 samuel'][24] = 7840;
        $book_index['1 samuel'][25] = 7862;
        $book_index['1 samuel'][26] = 7906;
        $book_index['1 samuel'][27] = 7931;
        $book_index['1 samuel'][28] = 7943;
        $book_index['1 samuel'][29] = 7968;
        $book_index['1 samuel'][30] = 7979;
        $book_index['1 samuel'][31] = 8010;
        $book_index['2 samuel'][1] = 8023;
        $book_index['2 samuel'][2] = 8050;
        $book_index['2 samuel'][3] = 8082;
        $book_index['2 samuel'][4] = 8121;
        $book_index['2 samuel'][5] = 8133;
        $book_index['2 samuel'][6] = 8158;
        $book_index['2 samuel'][7] = 8181;
        $book_index['2 samuel'][8] = 8210;
        $book_index['2 samuel'][9] = 8228;
        $book_index['2 samuel'][10] = 8241;
        $book_index['2 samuel'][11] = 8260;
        $book_index['2 samuel'][12] = 8287;
        $book_index['2 samuel'][13] = 8318;
        $book_index['2 samuel'][14] = 8357;
        $book_index['2 samuel'][15] = 8390;
        $book_index['2 samuel'][16] = 8427;
        $book_index['2 samuel'][17] = 8450;
        $book_index['2 samuel'][18] = 8479;
        $book_index['2 samuel'][19] = 8512;
        $book_index['2 samuel'][20] = 8555;
        $book_index['2 samuel'][21] = 8581;
        $book_index['2 samuel'][22] = 8603;
        $book_index['2 samuel'][23] = 8654;
        $book_index['2 samuel'][24] = 8693;
        $book_index['1 kings'][1] = 8718;
        $book_index['1 kings'][2] = 8771;
        $book_index['1 kings'][3] = 8817;
        $book_index['1 kings'][4] = 8845;
        $book_index['1 kings'][5] = 8879;
        $book_index['1 kings'][6] = 8897;
        $book_index['1 kings'][7] = 8935;
        $book_index['1 kings'][8] = 8986;
        $book_index['1 kings'][9] = 9052;
        $book_index['1 kings'][10] = 9080;
        $book_index['1 kings'][11] = 9109;
        $book_index['1 kings'][12] = 9152;
        $book_index['1 kings'][13] = 9185;
        $book_index['1 kings'][14] = 9219;
        $book_index['1 kings'][15] = 9250;
        $book_index['1 kings'][16] = 9284;
        $book_index['1 kings'][17] = 9318;
        $book_index['1 kings'][18] = 9342;
        $book_index['1 kings'][19] = 9388;
        $book_index['1 kings'][20] = 9409;
        $book_index['1 kings'][21] = 9452;
        $book_index['1 kings'][22] = 9481;
        $book_index['2 kings'][1] = 9534;
        $book_index['2 kings'][2] = 9552;
        $book_index['2 kings'][3] = 9577;
        $book_index['2 kings'][4] = 9604;
        $book_index['2 kings'][5] = 9648;
        $book_index['2 kings'][6] = 9675;
        $book_index['2 kings'][7] = 9708;
        $book_index['2 kings'][8] = 9728;
        $book_index['2 kings'][9] = 9757;
        $book_index['2 kings'][10] = 9794;
        $book_index['2 kings'][11] = 9830;
        $book_index['2 kings'][12] = 9851;
        $book_index['2 kings'][13] = 9872;
        $book_index['2 kings'][14] = 9897;
        $book_index['2 kings'][15] = 9926;
        $book_index['2 kings'][16] = 9964;
        $book_index['2 kings'][17] = 9984;
        $book_index['2 kings'][18] = 10025;
        $book_index['2 kings'][19] = 10062;
        $book_index['2 kings'][20] = 10099;
        $book_index['2 kings'][21] = 10120;
        $book_index['2 kings'][22] = 10146;
        $book_index['2 kings'][23] = 10166;
        $book_index['2 kings'][24] = 10203;
        $book_index['2 kings'][25] = 10223;
        $book_index['1 chronicles'][1] = 10253;
        $book_index['1 chronicles'][2] = 10307;
        $book_index['1 chronicles'][3] = 10362;
        $book_index['1 chronicles'][4] = 10386;
        $book_index['1 chronicles'][5] = 10429;
        $book_index['1 chronicles'][6] = 10455;
        $book_index['1 chronicles'][7] = 10536;
        $book_index['1 chronicles'][8] = 10576;
        $book_index['1 chronicles'][9] = 10616;
        $book_index['1 chronicles'][10] = 10660;
        $book_index['1 chronicles'][11] = 10674;
        $book_index['1 chronicles'][12] = 10721;
        $book_index['1 chronicles'][13] = 10761;
        $book_index['1 chronicles'][14] = 10775;
        $book_index['1 chronicles'][15] = 10792;
        $book_index['1 chronicles'][16] = 10821;
        $book_index['1 chronicles'][17] = 10864;
        $book_index['1 chronicles'][18] = 10891;
        $book_index['1 chronicles'][19] = 10908;
        $book_index['1 chronicles'][20] = 10927;
        $book_index['1 chronicles'][21] = 10935;
        $book_index['1 chronicles'][22] = 10965;
        $book_index['1 chronicles'][23] = 10984;
        $book_index['1 chronicles'][24] = 11016;
        $book_index['1 chronicles'][25] = 11047;
        $book_index['1 chronicles'][26] = 11078;
        $book_index['1 chronicles'][27] = 11110;
        $book_index['1 chronicles'][28] = 11144;
        $book_index['1 chronicles'][29] = 11165;
        $book_index['2 chronicles'][1] = 11195;
        $book_index['2 chronicles'][2] = 11212;
        $book_index['2 chronicles'][3] = 11230;
        $book_index['2 chronicles'][4] = 11247;
        $book_index['2 chronicles'][5] = 11269;
        $book_index['2 chronicles'][6] = 11283;
        $book_index['2 chronicles'][7] = 11325;
        $book_index['2 chronicles'][8] = 11347;
        $book_index['2 chronicles'][9] = 11365;
        $book_index['2 chronicles'][10] = 11396;
        $book_index['2 chronicles'][11] = 11415;
        $book_index['2 chronicles'][12] = 11438;
        $book_index['2 chronicles'][13] = 11454;
        $book_index['2 chronicles'][14] = 11476;
        $book_index['2 chronicles'][15] = 11491;
        $book_index['2 chronicles'][16] = 11510;
        $book_index['2 chronicles'][17] = 11524;
        $book_index['2 chronicles'][18] = 11543;
        $book_index['2 chronicles'][19] = 11577;
        $book_index['2 chronicles'][20] = 11588;
        $book_index['2 chronicles'][21] = 11625;
        $book_index['2 chronicles'][22] = 11645;
        $book_index['2 chronicles'][23] = 11657;
        $book_index['2 chronicles'][24] = 11678;
        $book_index['2 chronicles'][25] = 11705;
        $book_index['2 chronicles'][26] = 11733;
        $book_index['2 chronicles'][27] = 11756;
        $book_index['2 chronicles'][28] = 11765;
        $book_index['2 chronicles'][29] = 11792;
        $book_index['2 chronicles'][30] = 11828;
        $book_index['2 chronicles'][31] = 11855;
        $book_index['2 chronicles'][32] = 11876;
        $book_index['2 chronicles'][33] = 11909;
        $book_index['2 chronicles'][34] = 11934;
        $book_index['2 chronicles'][35] = 11967;
        $book_index['2 chronicles'][36] = 11994;
        $book_index['ezra'][1] = 12017;
        $book_index['ezra'][2] = 12028;
        $book_index['ezra'][3] = 12098;
        $book_index['ezra'][4] = 12111;
        $book_index['ezra'][5] = 12135;
        $book_index['ezra'][6] = 12152;
        $book_index['ezra'][7] = 12174;
        $book_index['ezra'][8] = 12202;
        $book_index['ezra'][9] = 12238;
        $book_index['ezra'][10] = 12253;
        $book_index['nehemiah'][1] = 12297;
        $book_index['nehemiah'][2] = 12308;
        $book_index['nehemiah'][3] = 12328;
        $book_index['nehemiah'][4] = 12360;
        $book_index['nehemiah'][5] = 12383;
        $book_index['nehemiah'][6] = 12402;
        $book_index['nehemiah'][7] = 12421;
        $book_index['nehemiah'][8] = 12494;
        $book_index['nehemiah'][9] = 12512;
        $book_index['nehemiah'][10] = 12550;
        $book_index['nehemiah'][11] = 12589;
        $book_index['nehemiah'][12] = 12625;
        $book_index['nehemiah'][13] = 12672;
        $book_index['esther'][1] = 12703;
        $book_index['esther'][2] = 12725;
        $book_index['esther'][3] = 12748;
        $book_index['esther'][4] = 12763;
        $book_index['esther'][5] = 12780;
        $book_index['esther'][6] = 12794;
        $book_index['esther'][7] = 12808;
        $book_index['esther'][8] = 12818;
        $book_index['esther'][9] = 12835;
        $book_index['esther'][10] = 12867;
        $book_index['job'][1] = 12870;
        $book_index['job'][2] = 12892;
        $book_index['job'][3] = 12905;
        $book_index['job'][4] = 12931;
        $book_index['job'][5] = 12952;
        $book_index['job'][6] = 12979;
        $book_index['job'][7] = 13009;
        $book_index['job'][8] = 13030;
        $book_index['job'][9] = 13052;
        $book_index['job'][10] = 13087;
        $book_index['job'][11] = 13109;
        $book_index['job'][12] = 13129;
        $book_index['job'][13] = 13154;
        $book_index['job'][14] = 13182;
        $book_index['job'][15] = 13204;
        $book_index['job'][16] = 13239;
        $book_index['job'][17] = 13261;
        $book_index['job'][18] = 13277;
        $book_index['job'][19] = 13298;
        $book_index['job'][20] = 13327;
        $book_index['job'][21] = 13356;
        $book_index['job'][22] = 13390;
        $book_index['job'][23] = 13420;
        $book_index['job'][24] = 13437;
        $book_index['job'][25] = 13462;
        $book_index['job'][26] = 13468;
        $book_index['job'][27] = 13482;
        $book_index['job'][28] = 13505;
        $book_index['job'][29] = 13533;
        $book_index['job'][30] = 13558;
        $book_index['job'][31] = 13589;
        $book_index['job'][32] = 13629;
        $book_index['job'][33] = 13651;
        $book_index['job'][34] = 13684;
        $book_index['job'][35] = 13721;
        $book_index['job'][36] = 13737;
        $book_index['job'][37] = 13770;
        $book_index['job'][38] = 13794;
        $book_index['job'][39] = 13835;
        $book_index['job'][40] = 13865;
        $book_index['job'][41] = 13889;
        $book_index['job'][42] = 13923;
        $book_index['psalms'][1] = 13940;
        $book_index['psalms'][2] = 13946;
        $book_index['psalms'][3] = 13958;
        $book_index['psalms'][4] = 13966;
        $book_index['psalms'][5] = 13974;
        $book_index['psalms'][6] = 13986;
        $book_index['psalms'][7] = 13996;
        $book_index['psalms'][8] = 14013;
        $book_index['psalms'][9] = 14022;
        $book_index['psalms'][10] = 14042;
        $book_index['psalms'][11] = 14060;
        $book_index['psalms'][12] = 14067;
        $book_index['psalms'][13] = 14075;
        $book_index['psalms'][14] = 14081;
        $book_index['psalms'][15] = 14088;
        $book_index['psalms'][16] = 14093;
        $book_index['psalms'][17] = 14104;
        $book_index['psalms'][18] = 14119;
        $book_index['psalms'][19] = 14169;
        $book_index['psalms'][20] = 14183;
        $book_index['psalms'][21] = 14192;
        $book_index['psalms'][22] = 14205;
        $book_index['psalms'][23] = 14236;
        $book_index['psalms'][24] = 14242;
        $book_index['psalms'][25] = 14252;
        $book_index['psalms'][26] = 14274;
        $book_index['psalms'][27] = 14286;
        $book_index['psalms'][28] = 14300;
        $book_index['psalms'][29] = 14309;
        $book_index['psalms'][30] = 14320;
        $book_index['psalms'][31] = 14332;
        $book_index['psalms'][32] = 14356;
        $book_index['psalms'][33] = 14367;
        $book_index['psalms'][34] = 14389;
        $book_index['psalms'][35] = 14411;
        $book_index['psalms'][36] = 14439;
        $book_index['psalms'][37] = 14451;
        $book_index['psalms'][38] = 14491;
        $book_index['psalms'][39] = 14513;
        $book_index['psalms'][40] = 14526;
        $book_index['psalms'][41] = 14543;
        $book_index['psalms'][42] = 14556;
        $book_index['psalms'][43] = 14567;
        $book_index['psalms'][44] = 14572;
        $book_index['psalms'][45] = 14598;
        $book_index['psalms'][46] = 14615;
        $book_index['psalms'][47] = 14626;
        $book_index['psalms'][48] = 14635;
        $book_index['psalms'][49] = 14649;
        $book_index['psalms'][50] = 14669;
        $book_index['psalms'][51] = 14692;
        $book_index['psalms'][52] = 14711;
        $book_index['psalms'][53] = 14720;
        $book_index['psalms'][54] = 14726;
        $book_index['psalms'][55] = 14733;
        $book_index['psalms'][56] = 14756;
        $book_index['psalms'][57] = 14769;
        $book_index['psalms'][58] = 14780;
        $book_index['psalms'][59] = 14791;
        $book_index['psalms'][60] = 14808;
        $book_index['psalms'][61] = 14820;
        $book_index['psalms'][62] = 14828;
        $book_index['psalms'][63] = 14840;
        $book_index['psalms'][64] = 14851;
        $book_index['psalms'][65] = 14861;
        $book_index['psalms'][66] = 14874;
        $book_index['psalms'][67] = 14894;
        $book_index['psalms'][68] = 14901;
        $book_index['psalms'][69] = 14936;
        $book_index['psalms'][70] = 14972;
        $book_index['psalms'][71] = 14977;
        $book_index['psalms'][72] = 15001;
        $book_index['psalms'][73] = 15021;
        $book_index['psalms'][74] = 15049;
        $book_index['psalms'][75] = 15072;
        $book_index['psalms'][76] = 15082;
        $book_index['psalms'][77] = 15094;
        $book_index['psalms'][78] = 15114;
        $book_index['psalms'][79] = 15186;
        $book_index['psalms'][80] = 15199;
        $book_index['psalms'][81] = 15218;
        $book_index['psalms'][82] = 15234;
        $book_index['psalms'][83] = 15242;
        $book_index['psalms'][84] = 15260;
        $book_index['psalms'][85] = 15272;
        $book_index['psalms'][86] = 15285;
        $book_index['psalms'][87] = 15302;
        $book_index['psalms'][88] = 15309;
        $book_index['psalms'][89] = 15327;
        $book_index['psalms'][90] = 15379;
        $book_index['psalms'][91] = 15396;
        $book_index['psalms'][92] = 15412;
        $book_index['psalms'][93] = 15427;
        $book_index['psalms'][94] = 15432;
        $book_index['psalms'][95] = 15455;
        $book_index['psalms'][96] = 15466;
        $book_index['psalms'][97] = 15479;
        $book_index['psalms'][98] = 15491;
        $book_index['psalms'][99] = 15500;
        $book_index['psalms'][100] = 15509;
        $book_index['psalms'][101] = 15514;
        $book_index['psalms'][102] = 15522;
        $book_index['psalms'][103] = 15550;
        $book_index['psalms'][104] = 15572;
        $book_index['psalms'][105] = 15607;
        $book_index['psalms'][106] = 15652;
        $book_index['psalms'][107] = 15700;
        $book_index['psalms'][108] = 15743;
        $book_index['psalms'][109] = 15756;
        $book_index['psalms'][110] = 15787;
        $book_index['psalms'][111] = 15794;
        $book_index['psalms'][112] = 15804;
        $book_index['psalms'][113] = 15814;
        $book_index['psalms'][114] = 15823;
        $book_index['psalms'][115] = 15831;
        $book_index['psalms'][116] = 15849;
        $book_index['psalms'][117] = 15868;
        $book_index['psalms'][118] = 15870;
        $book_index['psalms'][119] = 15899;
        $book_index['psalms'][120] = 16075;
        $book_index['psalms'][121] = 16082;
        $book_index['psalms'][122] = 16090;
        $book_index['psalms'][123] = 16099;
        $book_index['psalms'][124] = 16103;
        $book_index['psalms'][125] = 16111;
        $book_index['psalms'][126] = 16116;
        $book_index['psalms'][127] = 16122;
        $book_index['psalms'][128] = 16127;
        $book_index['psalms'][129] = 16133;
        $book_index['psalms'][130] = 16141;
        $book_index['psalms'][131] = 16149;
        $book_index['psalms'][132] = 16152;
        $book_index['psalms'][133] = 16170;
        $book_index['psalms'][134] = 16173;
        $book_index['psalms'][135] = 16176;
        $book_index['psalms'][136] = 16197;
        $book_index['psalms'][137] = 16223;
        $book_index['psalms'][138] = 16232;
        $book_index['psalms'][139] = 16240;
        $book_index['psalms'][140] = 16264;
        $book_index['psalms'][141] = 16277;
        $book_index['psalms'][142] = 16287;
        $book_index['psalms'][143] = 16294;
        $book_index['psalms'][144] = 16306;
        $book_index['psalms'][145] = 16321;
        $book_index['psalms'][146] = 16342;
        $book_index['psalms'][147] = 16352;
        $book_index['psalms'][148] = 16372;
        $book_index['psalms'][149] = 16386;
        $book_index['psalms'][150] = 16395;
        $book_index['proverbs'][1] = 16401;
        $book_index['proverbs'][2] = 16434;
        $book_index['proverbs'][3] = 16456;
        $book_index['proverbs'][4] = 16491;
        $book_index['proverbs'][5] = 16518;
        $book_index['proverbs'][6] = 16541;
        $book_index['proverbs'][7] = 16576;
        $book_index['proverbs'][8] = 16603;
        $book_index['proverbs'][9] = 16639;
        $book_index['proverbs'][10] = 16657;
        $book_index['proverbs'][11] = 16689;
        $book_index['proverbs'][12] = 16720;
        $book_index['proverbs'][13] = 16748;
        $book_index['proverbs'][14] = 16773;
        $book_index['proverbs'][15] = 16808;
        $book_index['proverbs'][16] = 16841;
        $book_index['proverbs'][17] = 16874;
        $book_index['proverbs'][18] = 16902;
        $book_index['proverbs'][19] = 16926;
        $book_index['proverbs'][20] = 16955;
        $book_index['proverbs'][21] = 16985;
        $book_index['proverbs'][22] = 17016;
        $book_index['proverbs'][23] = 17045;
        $book_index['proverbs'][24] = 17080;
        $book_index['proverbs'][25] = 17114;
        $book_index['proverbs'][26] = 17142;
        $book_index['proverbs'][27] = 17170;
        $book_index['proverbs'][28] = 17197;
        $book_index['proverbs'][29] = 17225;
        $book_index['proverbs'][30] = 17252;
        $book_index['proverbs'][31] = 17285;
        $book_index['ecclesiastes'][1] = 17316;
        $book_index['ecclesiastes'][2] = 17334;
        $book_index['ecclesiastes'][3] = 17360;
        $book_index['ecclesiastes'][4] = 17382;
        $book_index['ecclesiastes'][5] = 17398;
        $book_index['ecclesiastes'][6] = 17418;
        $book_index['ecclesiastes'][7] = 17430;
        $book_index['ecclesiastes'][8] = 17459;
        $book_index['ecclesiastes'][9] = 17476;
        $book_index['ecclesiastes'][10] = 17494;
        $book_index['ecclesiastes'][11] = 17514;
        $book_index['ecclesiastes'][12] = 17524;
        $book_index['song of solomon'][1] = 17538;
        $book_index['song of solomon'][2] = 17555;
        $book_index['song of solomon'][3] = 17572;
        $book_index['song of solomon'][4] = 17583;
        $book_index['song of solomon'][5] = 17599;
        $book_index['song of solomon'][6] = 17615;
        $book_index['song of solomon'][7] = 17628;
        $book_index['song of solomon'][8] = 17641;
        $book_index['isaiah'][1] = 17655;
        $book_index['isaiah'][2] = 17686;
        $book_index['isaiah'][3] = 17708;
        $book_index['isaiah'][4] = 17734;
        $book_index['isaiah'][5] = 17740;
        $book_index['isaiah'][6] = 17770;
        $book_index['isaiah'][7] = 17783;
        $book_index['isaiah'][8] = 17808;
        $book_index['isaiah'][9] = 17830;
        $book_index['isaiah'][10] = 17851;
        $book_index['isaiah'][11] = 17885;
        $book_index['isaiah'][12] = 17901;
        $book_index['isaiah'][13] = 17907;
        $book_index['isaiah'][14] = 17929;
        $book_index['isaiah'][15] = 17961;
        $book_index['isaiah'][16] = 17970;
        $book_index['isaiah'][17] = 17984;
        $book_index['isaiah'][18] = 17998;
        $book_index['isaiah'][19] = 18005;
        $book_index['isaiah'][20] = 18030;
        $book_index['isaiah'][21] = 18036;
        $book_index['isaiah'][22] = 18053;
        $book_index['isaiah'][23] = 18078;
        $book_index['isaiah'][24] = 18096;
        $book_index['isaiah'][25] = 18119;
        $book_index['isaiah'][26] = 18131;
        $book_index['isaiah'][27] = 18152;
        $book_index['isaiah'][28] = 18165;
        $book_index['isaiah'][29] = 18194;
        $book_index['isaiah'][30] = 18218;
        $book_index['isaiah'][31] = 18251;
        $book_index['isaiah'][32] = 18260;
        $book_index['isaiah'][33] = 18280;
        $book_index['isaiah'][34] = 18304;
        $book_index['isaiah'][35] = 18321;
        $book_index['isaiah'][36] = 18331;
        $book_index['isaiah'][37] = 18353;
        $book_index['isaiah'][38] = 18391;
        $book_index['isaiah'][39] = 18413;
        $book_index['isaiah'][40] = 18421;
        $book_index['isaiah'][41] = 18452;
        $book_index['isaiah'][42] = 18481;
        $book_index['isaiah'][43] = 18506;
        $book_index['isaiah'][44] = 18534;
        $book_index['isaiah'][45] = 18562;
        $book_index['isaiah'][46] = 18587;
        $book_index['isaiah'][47] = 18600;
        $book_index['isaiah'][48] = 18615;
        $book_index['isaiah'][49] = 18637;
        $book_index['isaiah'][50] = 18663;
        $book_index['isaiah'][51] = 18674;
        $book_index['isaiah'][52] = 18697;
        $book_index['isaiah'][53] = 18712;
        $book_index['isaiah'][54] = 18724;
        $book_index['isaiah'][55] = 18741;
        $book_index['isaiah'][56] = 18754;
        $book_index['isaiah'][57] = 18766;
        $book_index['isaiah'][58] = 18787;
        $book_index['isaiah'][59] = 18801;
        $book_index['isaiah'][60] = 18822;
        $book_index['isaiah'][61] = 18844;
        $book_index['isaiah'][62] = 18855;
        $book_index['isaiah'][63] = 18867;
        $book_index['isaiah'][64] = 18886;
        $book_index['isaiah'][65] = 18898;
        $book_index['isaiah'][66] = 18923;
        $book_index['jeremiah'][1] = 18947;
        $book_index['jeremiah'][2] = 18966;
        $book_index['jeremiah'][3] = 19003;
        $book_index['jeremiah'][4] = 19028;
        $book_index['jeremiah'][5] = 19059;
        $book_index['jeremiah'][6] = 19090;
        $book_index['jeremiah'][7] = 19120;
        $book_index['jeremiah'][8] = 19154;
        $book_index['jeremiah'][9] = 19176;
        $book_index['jeremiah'][10] = 19202;
        $book_index['jeremiah'][11] = 19227;
        $book_index['jeremiah'][12] = 19250;
        $book_index['jeremiah'][13] = 19267;
        $book_index['jeremiah'][14] = 19294;
        $book_index['jeremiah'][15] = 19316;
        $book_index['jeremiah'][16] = 19337;
        $book_index['jeremiah'][17] = 19358;
        $book_index['jeremiah'][18] = 19385;
        $book_index['jeremiah'][19] = 19408;
        $book_index['jeremiah'][20] = 19423;
        $book_index['jeremiah'][21] = 19441;
        $book_index['jeremiah'][22] = 19455;
        $book_index['jeremiah'][23] = 19485;
        $book_index['jeremiah'][24] = 19525;
        $book_index['jeremiah'][25] = 19535;
        $book_index['jeremiah'][26] = 19573;
        $book_index['jeremiah'][27] = 19597;
        $book_index['jeremiah'][28] = 19619;
        $book_index['jeremiah'][29] = 19636;
        $book_index['jeremiah'][30] = 19668;
        $book_index['jeremiah'][31] = 19692;
        $book_index['jeremiah'][32] = 19732;
        $book_index['jeremiah'][33] = 19776;
        $book_index['jeremiah'][34] = 19802;
        $book_index['jeremiah'][35] = 19824;
        $book_index['jeremiah'][36] = 19843;
        $book_index['jeremiah'][37] = 19875;
        $book_index['jeremiah'][38] = 19896;
        $book_index['jeremiah'][39] = 19924;
        $book_index['jeremiah'][40] = 19942;
        $book_index['jeremiah'][41] = 19958;
        $book_index['jeremiah'][42] = 19976;
        $book_index['jeremiah'][43] = 19998;
        $book_index['jeremiah'][44] = 20011;
        $book_index['jeremiah'][45] = 20041;
        $book_index['jeremiah'][46] = 20046;
        $book_index['jeremiah'][47] = 20074;
        $book_index['jeremiah'][48] = 20081;
        $book_index['jeremiah'][49] = 20128;
        $book_index['jeremiah'][50] = 20167;
        $book_index['jeremiah'][51] = 20213;
        $book_index['jeremiah'][52] = 20277;
        $book_index['lamentations'][1] = 20311;
        $book_index['lamentations'][2] = 20333;
        $book_index['lamentations'][3] = 20355;
        $book_index['lamentations'][4] = 20421;
        $book_index['lamentations'][5] = 20443;
        $book_index['ezekiel'][1] = 20465;
        $book_index['ezekiel'][2] = 20493;
        $book_index['ezekiel'][3] = 20503;
        $book_index['ezekiel'][4] = 20530;
        $book_index['ezekiel'][5] = 20547;
        $book_index['ezekiel'][6] = 20564;
        $book_index['ezekiel'][7] = 20578;
        $book_index['ezekiel'][8] = 20605;
        $book_index['ezekiel'][9] = 20623;
        $book_index['ezekiel'][10] = 20634;
        $book_index['ezekiel'][11] = 20656;
        $book_index['ezekiel'][12] = 20681;
        $book_index['ezekiel'][13] = 20709;
        $book_index['ezekiel'][14] = 20732;
        $book_index['ezekiel'][15] = 20755;
        $book_index['ezekiel'][16] = 20763;
        $book_index['ezekiel'][17] = 20826;
        $book_index['ezekiel'][18] = 20850;
        $book_index['ezekiel'][19] = 20882;
        $book_index['ezekiel'][20] = 20896;
        $book_index['ezekiel'][21] = 20945;
        $book_index['ezekiel'][22] = 20977;
        $book_index['ezekiel'][23] = 21008;
        $book_index['ezekiel'][24] = 21057;
        $book_index['ezekiel'][25] = 21084;
        $book_index['ezekiel'][26] = 21101;
        $book_index['ezekiel'][27] = 21122;
        $book_index['ezekiel'][28] = 21158;
        $book_index['ezekiel'][29] = 21184;
        $book_index['ezekiel'][30] = 21205;
        $book_index['ezekiel'][31] = 21231;
        $book_index['ezekiel'][32] = 21249;
        $book_index['ezekiel'][33] = 21281;
        $book_index['ezekiel'][34] = 21314;
        $book_index['ezekiel'][35] = 21345;
        $book_index['ezekiel'][36] = 21360;
        $book_index['ezekiel'][37] = 21398;
        $book_index['ezekiel'][38] = 21426;
        $book_index['ezekiel'][39] = 21449;
        $book_index['ezekiel'][40] = 21478;
        $book_index['ezekiel'][41] = 21527;
        $book_index['ezekiel'][42] = 21553;
        $book_index['ezekiel'][43] = 21573;
        $book_index['ezekiel'][44] = 21600;
        $book_index['ezekiel'][45] = 21631;
        $book_index['ezekiel'][46] = 21656;
        $book_index['ezekiel'][47] = 21680;
        $book_index['ezekiel'][48] = 21703;
        $book_index['daniel'][1] = 21738;
        $book_index['daniel'][2] = 21759;
        $book_index['daniel'][3] = 21808;
        $book_index['daniel'][4] = 21838;
        $book_index['daniel'][5] = 21875;
        $book_index['daniel'][6] = 21906;
        $book_index['daniel'][7] = 21934;
        $book_index['daniel'][8] = 21962;
        $book_index['daniel'][9] = 21989;
        $book_index['daniel'][10] = 22016;
        $book_index['daniel'][11] = 22037;
        $book_index['daniel'][12] = 22082;
        $book_index['hosea'][1] = 22095;
        $book_index['hosea'][2] = 22106;
        $book_index['hosea'][3] = 22129;
        $book_index['hosea'][4] = 22134;
        $book_index['hosea'][5] = 22153;
        $book_index['hosea'][6] = 22168;
        $book_index['hosea'][7] = 22179;
        $book_index['hosea'][8] = 22195;
        $book_index['hosea'][9] = 22209;
        $book_index['hosea'][10] = 22226;
        $book_index['hosea'][11] = 22241;
        $book_index['hosea'][12] = 22253;
        $book_index['hosea'][13] = 22267;
        $book_index['hosea'][14] = 22283;
        $book_index['joel'][1] = 22292;
        $book_index['joel'][2] = 22312;
        $book_index['joel'][3] = 22344;
        $book_index['amos'][1] = 22365;
        $book_index['amos'][2] = 22380;
        $book_index['amos'][3] = 22396;
        $book_index['amos'][4] = 22411;
        $book_index['amos'][5] = 22424;
        $book_index['amos'][6] = 22451;
        $book_index['amos'][7] = 22465;
        $book_index['amos'][8] = 22482;
        $book_index['amos'][9] = 22496;
        $book_index['obadiah'][1] = 22511;
        $book_index['jonah'][1] = 22532;
        $book_index['jonah'][2] = 22549;
        $book_index['jonah'][3] = 22559;
        $book_index['jonah'][4] = 22569;
        $book_index['micah'][1] = 22580;
        $book_index['micah'][2] = 22596;
        $book_index['micah'][3] = 22609;
        $book_index['micah'][4] = 22621;
        $book_index['micah'][5] = 22634;
        $book_index['micah'][6] = 22649;
        $book_index['micah'][7] = 22665;
        $book_index['nahum'][1] = 22685;
        $book_index['nahum'][2] = 22700;
        $book_index['nahum'][3] = 22713;
        $book_index['habakkuk'][1] = 22732;
        $book_index['habakkuk'][2] = 22749;
        $book_index['habakkuk'][3] = 22769;
        $book_index['zephaniah'][1] = 22788;
        $book_index['zephaniah'][2] = 22806;
        $book_index['zephaniah'][3] = 22821;
        $book_index['haggai'][1] = 22841;
        $book_index['haggai'][2] = 22856;
        $book_index['zechariah'][1] = 22879;
        $book_index['zechariah'][2] = 22900;
        $book_index['zechariah'][3] = 22913;
        $book_index['zechariah'][4] = 22923;
        $book_index['zechariah'][5] = 22937;
        $book_index['zechariah'][6] = 22948;
        $book_index['zechariah'][7] = 22963;
        $book_index['zechariah'][8] = 22977;
        $book_index['zechariah'][9] = 23000;
        $book_index['zechariah'][10] = 23017;
        $book_index['zechariah'][11] = 23029;
        $book_index['zechariah'][12] = 23046;
        $book_index['zechariah'][13] = 23060;
        $book_index['zechariah'][14] = 23069;
        $book_index['malachi'][1] = 23090;
        $book_index['malachi'][2] = 23104;
        $book_index['malachi'][3] = 23121;
        $book_index['malachi'][4] = 23139;
        $book_index['matthew'][1] = 23145;
        $book_index['matthew'][2] = 23170;
        $book_index['matthew'][3] = 23193;
        $book_index['matthew'][4] = 23210;
        $book_index['matthew'][5] = 23235;
        $book_index['matthew'][6] = 23283;
        $book_index['matthew'][7] = 23317;
        $book_index['matthew'][8] = 23346;
        $book_index['matthew'][9] = 23380;
        $book_index['matthew'][10] = 23418;
        $book_index['matthew'][11] = 23460;
        $book_index['matthew'][12] = 23490;
        $book_index['matthew'][13] = 23540;
        $book_index['matthew'][14] = 23598;
        $book_index['matthew'][15] = 23634;
        $book_index['matthew'][16] = 23673;
        $book_index['matthew'][17] = 23701;
        $book_index['matthew'][18] = 23728;
        $book_index['matthew'][19] = 23763;
        $book_index['matthew'][20] = 23793;
        $book_index['matthew'][21] = 23827;
        $book_index['matthew'][22] = 23873;
        $book_index['matthew'][23] = 23919;
        $book_index['matthew'][24] = 23958;
        $book_index['matthew'][25] = 24009;
        $book_index['matthew'][26] = 24055;
        $book_index['matthew'][27] = 24130;
        $book_index['matthew'][28] = 24196;
        $book_index['mark'][1] = 24216;
        $book_index['mark'][2] = 24261;
        $book_index['mark'][3] = 24289;
        $book_index['mark'][4] = 24324;
        $book_index['mark'][5] = 24365;
        $book_index['mark'][6] = 24408;
        $book_index['mark'][7] = 24464;
        $book_index['mark'][8] = 24501;
        $book_index['mark'][9] = 24539;
        $book_index['mark'][10] = 24589;
        $book_index['mark'][11] = 24641;
        $book_index['mark'][12] = 24674;
        $book_index['mark'][13] = 24718;
        $book_index['mark'][14] = 24755;
        $book_index['mark'][15] = 24827;
        $book_index['mark'][16] = 24874;
        $book_index['luke'][1] = 24894;
        $book_index['luke'][2] = 24974;
        $book_index['luke'][3] = 25026;
        $book_index['luke'][4] = 25064;
        $book_index['luke'][5] = 25108;
        $book_index['luke'][6] = 25147;
        $book_index['luke'][7] = 25196;
        $book_index['luke'][8] = 25246;
        $book_index['luke'][9] = 25302;
        $book_index['luke'][10] = 25364;
        $book_index['luke'][11] = 25406;
        $book_index['luke'][12] = 25460;
        $book_index['luke'][13] = 25519;
        $book_index['luke'][14] = 25554;
        $book_index['luke'][15] = 25589;
        $book_index['luke'][16] = 25621;
        $book_index['luke'][17] = 25652;
        $book_index['luke'][18] = 25689;
        $book_index['luke'][19] = 25732;
        $book_index['luke'][20] = 25780;
        $book_index['luke'][21] = 25827;
        $book_index['luke'][22] = 25865;
        $book_index['luke'][23] = 25936;
        $book_index['luke'][24] = 25992;
        $book_index['john'][1] = 26045;
        $book_index['john'][2] = 26096;
        $book_index['john'][3] = 26121;
        $book_index['john'][4] = 26157;
        $book_index['john'][5] = 26211;
        $book_index['john'][6] = 26258;
        $book_index['john'][7] = 26329;
        $book_index['john'][8] = 26382;
        $book_index['john'][9] = 26441;
        $book_index['john'][10] = 26482;
        $book_index['john'][11] = 26524;
        $book_index['john'][12] = 26581;
        $book_index['john'][13] = 26631;
        $book_index['john'][14] = 26669;
        $book_index['john'][15] = 26700;
        $book_index['john'][16] = 26727;
        $book_index['john'][17] = 26760;
        $book_index['john'][18] = 26786;
        $book_index['john'][19] = 26826;
        $book_index['john'][20] = 26868;
        $book_index['john'][21] = 26899;
        $book_index['acts'][1] = 26924;
        $book_index['acts'][2] = 26950;
        $book_index['acts'][3] = 26997;
        $book_index['acts'][4] = 27023;
        $book_index['acts'][5] = 27060;
        $book_index['acts'][6] = 27102;
        $book_index['acts'][7] = 27117;
        $book_index['acts'][8] = 27177;
        $book_index['acts'][9] = 27217;
        $book_index['acts'][10] = 27260;
        $book_index['acts'][11] = 27308;
        $book_index['acts'][12] = 27338;
        $book_index['acts'][13] = 27363;
        $book_index['acts'][14] = 27415;
        $book_index['acts'][15] = 27443;
        $book_index['acts'][16] = 27484;
        $book_index['acts'][17] = 27524;
        $book_index['acts'][18] = 27558;
        $book_index['acts'][19] = 27586;
        $book_index['acts'][20] = 27627;
        $book_index['acts'][21] = 27665;
        $book_index['acts'][22] = 27705;
        $book_index['acts'][23] = 27735;
        $book_index['acts'][24] = 27770;
        $book_index['acts'][25] = 27797;
        $book_index['acts'][26] = 27824;
        $book_index['acts'][27] = 27856;
        $book_index['acts'][28] = 27900;
        $book_index['romans'][1] = 27931;
        $book_index['romans'][2] = 27963;
        $book_index['romans'][3] = 27992;
        $book_index['romans'][4] = 28023;
        $book_index['romans'][5] = 28048;
        $book_index['romans'][6] = 28069;
        $book_index['romans'][7] = 28092;
        $book_index['romans'][8] = 28117;
        $book_index['romans'][9] = 28156;
        $book_index['romans'][10] = 28189;
        $book_index['romans'][11] = 28210;
        $book_index['romans'][12] = 28246;
        $book_index['romans'][13] = 28267;
        $book_index['romans'][14] = 28281;
        $book_index['romans'][15] = 28304;
        $book_index['romans'][16] = 28337;
        $book_index['1 corinthians'][1] = 28364;
        $book_index['1 corinthians'][2] = 28395;
        $book_index['1 corinthians'][3] = 28411;
        $book_index['1 corinthians'][4] = 28434;
        $book_index['1 corinthians'][5] = 28455;
        $book_index['1 corinthians'][6] = 28468;
        $book_index['1 corinthians'][7] = 28488;
        $book_index['1 corinthians'][8] = 28528;
        $book_index['1 corinthians'][9] = 28541;
        $book_index['1 corinthians'][10] = 28568;
        $book_index['1 corinthians'][11] = 28601;
        $book_index['1 corinthians'][12] = 28635;
        $book_index['1 corinthians'][13] = 28666;
        $book_index['1 corinthians'][14] = 28679;
        $book_index['1 corinthians'][15] = 28719;
        $book_index['1 corinthians'][16] = 28777;
        $book_index['2 corinthians'][1] = 28801;
        $book_index['2 corinthians'][2] = 28825;
        $book_index['2 corinthians'][3] = 28842;
        $book_index['2 corinthians'][4] = 28860;
        $book_index['2 corinthians'][5] = 28878;
        $book_index['2 corinthians'][6] = 28899;
        $book_index['2 corinthians'][7] = 28917;
        $book_index['2 corinthians'][8] = 28933;
        $book_index['2 corinthians'][9] = 28957;
        $book_index['2 corinthians'][10] = 28972;
        $book_index['2 corinthians'][11] = 28990;
        $book_index['2 corinthians'][12] = 29023;
        $book_index['2 corinthians'][13] = 29044;
        $book_index['galatians'][1] = 29058;
        $book_index['galatians'][2] = 29082;
        $book_index['galatians'][3] = 29103;
        $book_index['galatians'][4] = 29132;
        $book_index['galatians'][5] = 29163;
        $book_index['galatians'][6] = 29189;
        $book_index['ephesians'][1] = 29207;
        $book_index['ephesians'][2] = 29230;
        $book_index['ephesians'][3] = 29252;
        $book_index['ephesians'][4] = 29273;
        $book_index['ephesians'][5] = 29305;
        $book_index['ephesians'][6] = 29338;
        $book_index['philippians'][1] = 29362;
        $book_index['philippians'][2] = 29392;
        $book_index['philippians'][3] = 29422;
        $book_index['philippians'][4] = 29443;
        $book_index['colossians'][1] = 29466;
        $book_index['colossians'][2] = 29495;
        $book_index['colossians'][3] = 29518;
        $book_index['colossians'][4] = 29543;
        $book_index['1 thessalonians'][1] = 29561;
        $book_index['1 thessalonians'][2] = 29571;
        $book_index['1 thessalonians'][3] = 29591;
        $book_index['1 thessalonians'][4] = 29604;
        $book_index['1 thessalonians'][5] = 29622;
        $book_index['2 thessalonians'][1] = 29650;
        $book_index['2 thessalonians'][2] = 29662;
        $book_index['2 thessalonians'][3] = 29679;
        $book_index['1 timothy'][1] = 29697;
        $book_index['1 timothy'][2] = 29717;
        $book_index['1 timothy'][3] = 29732;
        $book_index['1 timothy'][4] = 29748;
        $book_index['1 timothy'][5] = 29764;
        $book_index['1 timothy'][6] = 29789;
        $book_index['2 timothy'][1] = 29810;
        $book_index['2 timothy'][2] = 29828;
        $book_index['2 timothy'][3] = 29854;
        $book_index['2 timothy'][4] = 29871;
        $book_index['titus'][1] = 29893;
        $book_index['titus'][2] = 29909;
        $book_index['titus'][3] = 29924;
        $book_index['philemon'][1] = 29939;
        $book_index['hebrews'][1] = 29964;
        $book_index['hebrews'][2] = 29978;
        $book_index['hebrews'][3] = 29996;
        $book_index['hebrews'][4] = 30015;
        $book_index['hebrews'][5] = 30031;
        $book_index['hebrews'][6] = 30045;
        $book_index['hebrews'][7] = 30065;
        $book_index['hebrews'][8] = 30093;
        $book_index['hebrews'][9] = 30106;
        $book_index['hebrews'][10] = 30134;
        $book_index['hebrews'][11] = 30173;
        $book_index['hebrews'][12] = 30213;
        $book_index['hebrews'][13] = 30242;
        $book_index['james'][1] = 30267;
        $book_index['james'][2] = 30294;
        $book_index['james'][3] = 30320;
        $book_index['james'][4] = 30338;
        $book_index['james'][5] = 30355;
        $book_index['1 peter'][1] = 30375;
        $book_index['1 peter'][2] = 30400;
        $book_index['1 peter'][3] = 30425;
        $book_index['1 peter'][4] = 30447;
        $book_index['1 peter'][5] = 30466;
        $book_index['2 peter'][1] = 30480;
        $book_index['2 peter'][2] = 30501;
        $book_index['2 peter'][3] = 30523;
        $book_index['1 john'][1] = 30541;
        $book_index['1 john'][2] = 30551;
        $book_index['1 john'][3] = 30580;
        $book_index['1 john'][4] = 30604;
        $book_index['1 john'][5] = 30625;
        $book_index['2 john'][1] = 30646;
        $book_index['3 john'][1] = 30659;
        $book_index['jude'][1] = 30673;
        $book_index['revelation'][1] = 30698;
        $book_index['revelation'][2] = 30718;
        $book_index['revelation'][3] = 30747;
        $book_index['revelation'][4] = 30769;
        $book_index['revelation'][5] = 30780;
        $book_index['revelation'][6] = 30794;
        $book_index['revelation'][7] = 30811;
        $book_index['revelation'][8] = 30828;
        $book_index['revelation'][9] = 30841;
        $book_index['revelation'][10] = 30862;
        $book_index['revelation'][11] = 30873;
        $book_index['revelation'][12] = 30892;
        $book_index['revelation'][13] = 30909;
        $book_index['revelation'][14] = 30927;
        $book_index['revelation'][15] = 30947;
        $book_index['revelation'][16] = 30955;
        $book_index['revelation'][17] = 30976;
        $book_index['revelation'][18] = 30994;
        $book_index['revelation'][19] = 31018;
        $book_index['revelation'][20] = 31039;
        $book_index['revelation'][21] = 31054;
        $book_index['revelation'][22] = 31081;
        return $book_index;
    }
}